::: beignet.apply_rotation_vector
::: beignet.compose_rotation_vector
::: beignet.invert_rotation_vector
::: beignet.random_rotation_vector
::: beignet.rotation_vector_identity
::: beignet.rotation_vector_magnitude
::: beignet.rotation_vector_mean
::: beignet.rotation_vector_to_euler_angle
::: beignet.rotation_vector_to_quaternion
::: beignet.rotation_vector_to_rotation_matrix
